@@ -26,6 +26,19 @@
 #include "babl-internal.h"
 #include "git-version.h"
 
+#ifdef _WIN32
+#ifndef S_IRWXU
+  #define S_IRWXU 0000700
+#endif
+#if !defined(S_ISREG) && defined(S_IFMT) && defined(S_IFREG)
+  #define S_ISREG(m) (((m) & S_IFMT) == S_IFREG)
+#endif
+#if !defined(S_ISDIR) && defined(S_IFMT) && defined(S_IFDIR)
+  #define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
+#endif
+#define strtok_r strtok_s
+#endif
+
 #ifdef _WIN32
 #define FALLBACK_CACHE_PATH  "C:/babl-fishes.txt"
 #else
