@@ -67,7 +67,7 @@ babl_dir_list (void)
       sep2 = strrchr (filename, BABL_DIR_SEPARATOR[0]);
       if (sep2 != NULL)
         {
-          if (strcasecmp (sep2 + 1, "bin") == 0)
+          if (_stricmp (sep2 + 1, "bin") == 0)
             {
               char* filename_tmp;
               *(++sep2) = '\0';
