@@ -29,9 +29,10 @@
 #include <babl/babl.h>
 
 
-static const Babl * babl_cli_get_space   (const char    *path,
-                                          BablIccIntent  intent);
-static void         babl_cli_print_usage (FILE          *stream);
+static const Babl * babl_cli_get_space     (const char    *path,
+                                            BablIccIntent  intent);
+static void         babl_cli_print_version (FILE          *stream);
+static void         babl_cli_print_usage   (FILE          *stream);
 
 
 int
@@ -139,6 +140,13 @@ main (int    argc,
         {
           babl_cli_print_usage (stdout);
 
+          return 0;
+        }
+      else if (strcmp (argv[i], "--version") == 0 ||
+               strcmp (argv[i], "-v") == 0)
+        {
+          babl_cli_print_version (stdout);
+
           return 0;
         }
       else if (strcmp (argv[i], "--from") == 0 ||
@@ -304,6 +312,11 @@ main (int    argc,
              {
                /* Pass. */
              }
+          else if (strcmp (argv[i], "--version") == 0 ||
+                   strcmp (argv[i], "-v") == 0)
+             {
+               /* Pass. */
+             }
           else if (strcmp (argv[i], "--from") == 0 ||
                    strcmp (argv[i], "-f") == 0)
             {
@@ -603,6 +616,14 @@ babl_cli_get_space (const char    *path,
   return space;
 }
 
+static void
+babl_cli_print_version (FILE *stream)
+{
+  fprintf (stream,
+           BABL_VERSION
+           "\n");
+}
+
 static void
 babl_cli_print_usage (FILE *stream)
 {
@@ -613,6 +634,8 @@ babl_cli_print_usage (FILE *stream)
            "  Options:\n"
            "     -h, --help            this help information\n"
            "\n"
+           "     -v, --version         Babl version\n"
+           "\n"
            "     -f, --from            input Babl format\n"
            "\n"
            "     -t, --to              output Babl format\n"
