@@ -24,8 +24,7 @@
 #include "common.inc"
 
 int
-main (int    argc,
-      char **argv)
+main (void)
 {
   int OK = 1;
   babl_init ();
